@@ -18,9 +18,9 @@ try:
 except ImportError:
     # https://peps.python.org/pep-0680/
     try:
-        import tomllib as tomli  # type: ignore
+        import tomllib as tomli
     except ImportError:
-        tomli = None   # type: ignore[assignment]
+        tomli = None
 
 
 @dataclasses.dataclass
@@ -29,9 +29,11 @@ class Config:
     depth: int = 40
     allow_unsynced: bool = False
     preserve_position: bool = False
+    sort_baseline: bool = False
     hide_stats: bool = False
     no_colors: bool = bool(os.environ.get('NO_COLOR'))
     ignore: list[str] = dataclasses.field(default_factory=list)
+    ignore_categories: list[str] = dataclasses.field(default_factory=list)
     default_branch: str = ''
 
     @classmethod
@@ -60,24 +62,32 @@ class Config:
         )
 
         add(
-            '--allow-unsynced', action='store_true',
+            '--allow-unsynced', action='store_const', const=True,
             help='do not fail for resolved violations.'
         )
         add(
-            '--preserve-position', action='store_true',
+            '--preserve-position', action='store_const', const=True,
             help='do not remove line number from the baseline.',
         )
         add(
-            '--hide-stats', action='store_true',
+            '--sort-baseline', action='store_const', const=True,
+            help='sort the baseline file.',
+        )
+        add(
+            '--hide-stats', action='store_const', const=True,
             help='do not show stats at the end.',
         )
         add(
-            '--no-colors', action='store_true',
+            '--no-colors', action='store_const', const=True,
             help='disable colored output. Has no effect on the output of mypy.',
         )
         add(
             '--ignore', nargs='*',
-            help='regexes for messages to ignore.',
+            help='regexes for messages to ignore, e.g. ".*Enum.*"',
+        )
+        add(
+            '--ignore-categories', nargs='*',
+            help='categories of mypy errors to ignore, e.g. "note" or "call-arg"',
         )
         add(
             '--default-branch',
@@ -131,3 +141,8 @@ class Config:
         """Check if the message matches any ignore pattern from the config.
         """
         return any(rex.fullmatch(msg) for rex in self._ignore_regexes)
+
+    def is_ignored_category(self, category: str) -> bool:
+        """Check if the category matches any ignore pattern from the config.
+        """
+        return category in self.ignore_categories
