@@ -27,6 +27,8 @@ class Filter(Command):
                 continue
             if self.config.is_ignored(error.message):
                 continue
+            if self.config.is_ignored_category(error.category):
+                continue
             clean_line = error.get_clean_line(self.config)
             try:
                 baseline.remove(clean_line)
@@ -37,7 +39,10 @@ class Filter(Command):
                 unresolved_errors.append(error)
 
         fixed_errors: list[Error] = []
+
         for line in baseline:
+            if not line:  # Skip empty lines
+                continue
             error = Error.new(line)
             if error is None:
                 print(f'invalid baseline, cannot parse line: {line}')
